cognet API documentation
Description: Cognet …

# Package `cognet`

# Cognet

## Description

Inferring Emergent Structures in Survey Response Data

## Installation

       pip install cognet

or

       pip3 install cognet --user

## Notes

Depends on the `quasinet` package, which is installed automatically.

## Quickstart

Data format

## Examples

- Examples directory on github repo
- Medium article

## Faq

- `joblib errors`: might require latest joblib version. In some python 3.8 installations, joblib 0.16.0 might be required. This is an open issue which is being addressed.

## Contact

Zero Knowledge Discovery, The University of Chicago

mailto: ishanu@uchicago.edu

Expand source code

    """
    # Cognet

    Description:
        Inferring Emergent Structures in Survey Response Data

    ---

    Installation:
       ```
          pip install cognet
       ```
       or
       ```
          pip3 install cognet --user
       ```

    Notes:
       Depends on the `quasinet` package, which is
       installed automatically.

    ---

    Quickstart:
       Data format

    Examples:
       + Examples directory on github repo
       + Medium article

    ---

    FAQ:
      + <u>`joblib errors`:</u> might require latest joblib version. In some python 3.8 installations, joblib 0.16.0 might be required. This is an open issue which is being addressed.

    ---

    Contact:
      [Zero Knowledge Discovery](zed.uchicago.edu), The University of Chicago

      mailto: ishanu@uchicago.edu

    """

## Sub-modules

`cognet.cognet`
`cognet.dataFormatter`
`cognet.model`
`cognet.util`
`cognet.viz`